@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: downloader-view.c,v 1.66 2004/07/06 14:00:51 xan Exp $
+ *  $Id: downloader-view.c,v 1.68 2004/07/24 10:17:29 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -174,11 +174,8 @@ status_icon_activated (EggStatusIcon *icon, DownloaderView *dv)
 static void
 show_status_icon (DownloaderView *dv)
 {
-	GdkPixbuf *pixbuf;
-
-	pixbuf = gdk_pixbuf_new_from_file (ephy_file ("epiphany-download.png"), NULL);
-	dv->priv->status_icon = egg_status_icon_new_from_pixbuf (pixbuf);
-	g_object_unref (pixbuf);
+	dv->priv->status_icon =
+		egg_status_icon_new_from_stock (EPHY_STOCK_DOWNLOAD);
 
 	g_signal_connect (dv->priv->status_icon, "activate",
 			  G_CALLBACK (status_icon_activated), dv);
@@ -502,6 +499,7 @@ downloader_view_add_download (DownloaderView *dv,
 	gtk_icon_info_free (icon_info);
 	
 	pixbuf = gdk_pixbuf_new_from_file_at_size (icon_name, width, height, NULL);
+	g_free (icon_name);
 	gtk_list_store_set (GTK_LIST_STORE (dv->priv->model),
 			    &iter, COL_IMAGE, pixbuf, -1);
 	if (pixbuf)
