@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.h,v 1.24 2004/07/27 11:04:52 chpe Exp $
+ *  $Id: ephy-embed-single.h,v 1.25 2004/08/08 11:32:18 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_SINGLE_H
@@ -50,37 +50,39 @@ struct _EphyEmbedSingleIface
 
 	/* Methods */
 
-	void	 (* open_window)	 (EphyEmbedSingle *single,
-					  EphyEmbed *parent,
-					  const char *address,
-					  const char *features);
-	void	 (* clear_cache)         (EphyEmbedSingle *shell);
-	void	 (* clear_auth_cache)	 (EphyEmbedSingle *shell);
-	void	 (* set_offline_mode)    (EphyEmbedSingle *shell,
-					  gboolean offline);
-	gboolean (* get_offline_mode)	 (EphyEmbedSingle *single);
-	GList *	 (* get_font_list)	 (EphyEmbedSingle *shell,
-					  const char *langGroup);
-};
-
-GType	 ephy_embed_single_get_type		(void);
-
-void	 ephy_embed_single_open_window		(EphyEmbedSingle *single,
+	GtkWidget *	(* open_window)		(EphyEmbedSingle *single,
 						 EphyEmbed *parent,
 						 const char *address,
+						 const char *name,
 						 const char *features);
-
-void	 ephy_embed_single_clear_cache		(EphyEmbedSingle *single);
-
-void	 ephy_embed_single_clear_auth_cache	(EphyEmbedSingle *single);
-
-void	 ephy_embed_single_set_offline_mode	(EphyEmbedSingle *single,
+	void		(* clear_cache)		(EphyEmbedSingle *shell);
+	void		(* clear_auth_cache)	(EphyEmbedSingle *shell);
+	void		(* set_offline_mode)	(EphyEmbedSingle *shell,
 						 gboolean offline);
+	gboolean	(* get_offline_mode)	(EphyEmbedSingle *single);
+	GList *		(* get_font_list)	(EphyEmbedSingle *shell,
+						 const char *langGroup);
+};
 
-gboolean ephy_embed_single_get_offline_mode	(EphyEmbedSingle *single);
+GType		ephy_embed_single_get_type		(void);
 
-GList	*ephy_embed_single_get_font_list	(EphyEmbedSingle *single,
-						 const char *lang_group);
+GtkWidget      *ephy_embed_single_open_window		(EphyEmbedSingle *single,
+							 EphyEmbed *parent,
+							 const char *address,
+							 const char *name,
+							 const char *features);
+
+void		ephy_embed_single_clear_cache		(EphyEmbedSingle *single);
+
+void		ephy_embed_single_clear_auth_cache	(EphyEmbedSingle *single);
+
+void		ephy_embed_single_set_offline_mode	(EphyEmbedSingle *single,
+							 gboolean offline);
+
+gboolean	ephy_embed_single_get_offline_mode	(EphyEmbedSingle *single);
+
+GList		*ephy_embed_single_get_font_list	(EphyEmbedSingle *single,
+							 const char *lang_group);
 
 G_END_DECLS
 
