@@ -18,32 +18,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.47.4.6 2004/08/27 20:55:44 chpe Exp $
+ *  $Id: ContentHandler.cpp,v 1.60 2004/07/31 13:41:09 chpe Exp $
  */
 
+#include "mozilla-config.h"
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "ContentHandler.h"
-#include "MozillaPrivate.h"
-#include "MozDownload.h"
-
-#include "nsCOMPtr.h"
-#include "nsString.h"
-#include "nsIURL.h"
-#include "nsILocalFile.h"
-#include "nsIMIMEInfo.h"
-#include "nsIInterfaceRequestorUtils.h"
-
-#include "ephy-prefs.h"
-#include "eel-gconf-extensions.h"
-#include "ephy-embed-single.h"
-#include "ephy-embed-shell.h"
-#include "ephy-file-chooser.h"
-#include "ephy-gui.h"
-#include "ephy-debug.h"
-
 #include <gtk/gtkimage.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
@@ -54,17 +37,37 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
 
+#include <nsMemory.h>
+#include <nsIURL.h>
+#include <nsILocalFile.h>
+#include <nsIMIMEInfo.h>
+#include <nsIInterfaceRequestorUtils.h>
+#include <nsCExternalHandlerService.h>
+
+#include "ephy-prefs.h"
+#include "ephy-embed-single.h"
+#include "ephy-embed-shell.h"
+#include "ephy-file-chooser.h"
+#include "ephy-stock-icons.h"
+#include "ephy-gui.h"
+#include "ephy-debug.h"
+#include "eel-gconf-extensions.h"
+
+#include "ContentHandler.h"
+#include "MozillaPrivate.h"
+#include "MozDownload.h"
+
 class GContentHandler;
 
 NS_IMPL_ISUPPORTS1(GContentHandler, nsIHelperAppLauncherDialog)
 
-#if MOZILLA_SNAPSHOT < 20
-GContentHandler::GContentHandler() : mMimeType(nsnull)
+#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+GContentHandler::GContentHandler()
 {
 	LOG ("GContentHandler ctor (%p)", this)
 }
 #else
-GContentHandler::GContentHandler()
+GContentHandler::GContentHandler() : mMimeType(nsnull)
 {
 	LOG ("GContentHandler ctor (%p)", this)
 }
@@ -74,7 +77,7 @@ GContentHandler::~GContentHandler()
 {
 	LOG ("GContentHandler dtor (%p)", this)
 
-#if MOZILLA_SNAPSHOT < 20
+#if !MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
 	nsMemory::Free (mMimeType);
 #endif
 }
@@ -83,15 +86,10 @@ GContentHandler::~GContentHandler()
 // begin nsIHelperAppLauncher impl
 ////////////////////////////////////////////////////////////////////////////////
 
-#if MOZILLA_SNAPSHOT > 9
 /* void show (in nsIHelperAppLauncher aLauncher, in nsISupports aContext); */
 NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 				    nsISupports *aContext,
 				    PRBool aForced)
-#else
-NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
-				    nsISupports *aContext)
-#endif
 {
 	nsresult rv;
 	EphyEmbedSingle *single;
@@ -103,11 +101,11 @@ NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
-#if MOZILLA_SNAPSHOT < 20
-	g_signal_emit_by_name (single, "handle_content", mMimeType,
+#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+	g_signal_emit_by_name (single, "handle_content", mMimeType.get(),
 			       mUrl.get(), &handled);
 #else
-	g_signal_emit_by_name (single, "handle_content", mMimeType.get(),
+	g_signal_emit_by_name (single, "handle_content", mMimeType,
 			       mUrl.get(), &handled);
 #endif
 
@@ -125,9 +123,7 @@ NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 
 /* nsILocalFile promptForSaveToFile (in nsISupports aWindowContext, in wstring aDefaultFile, in wstring aSuggestedFileExtension); */
 NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
-#if MOZILLA_SNAPSHOT > 10
-				    nsIHelperAppLauncher *aLauncher,
-#endif				    
+				    nsIHelperAppLauncher *aLauncher,			    
 				    nsISupports *aWindowContext,
 				    const PRUnichar *aDefaultFile,
 				    const PRUnichar *aSuggestedFileExtension,
@@ -136,11 +132,14 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 	EphyFileChooser *dialog;
 	gint response;
 	char *filename = NULL;
+	nsEmbedCString defaultFile;
+
+	NS_UTF16ToCString (nsEmbedString (aDefaultFile),
+			   NS_CSTRING_ENCODING_UTF8, defaultFile);
 
 	if (mAction != CONTENT_ACTION_SAVEAS)
 	{
-		return BuildDownloadPath (NS_ConvertUCS2toUTF8 (aDefaultFile).get(),
-					  _retval);
+		return BuildDownloadPath (defaultFile.get(), _retval);
 	}
 
 	nsCOMPtr<nsIDOMWindow> parentDOMWindow = do_GetInterface (aWindowContext);
@@ -148,9 +147,9 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 
 	dialog = ephy_file_chooser_new (_("Save"), parentWindow,
 					GTK_FILE_CHOOSER_ACTION_SAVE,
-					CONF_STATE_SAVE_DIR);
-	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog),
-					   NS_ConvertUCS2toUTF8 (aDefaultFile).get());
+					CONF_STATE_SAVE_DIR,
+					EPHY_FILE_FILTER_ALL);
+	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), defaultFile.get());
 
 	do
 	{
@@ -162,10 +161,10 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 
 	if (response == GTK_RESPONSE_ACCEPT)
 	{
-		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-
 		nsCOMPtr <nsILocalFile> destFile (do_CreateInstance(NS_LOCAL_FILE_CONTRACTID));
-		destFile->InitWithNativePath (nsDependentCString (filename));
+		NS_ENSURE_TRUE (destFile, NS_ERROR_FAILURE);
+
+		destFile->InitWithNativePath (nsEmbedCString (filename));
 		g_free (filename);
 
 		NS_IF_ADDREF (*_retval = destFile);
@@ -183,15 +182,6 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 	}
 }
 
-#if MOZILLA_SNAPSHOT < 10
-/* void showProgressDialog (in nsIHelperAppLauncher aLauncher, in nsISupports aContext); */
-NS_METHOD GContentHandler::ShowProgressDialog(nsIHelperAppLauncher *aLauncher,
-					      nsISupports *aContext)
-{
-	return NS_ERROR_NOT_IMPLEMENTED;
-}
-#endif
-
 NS_METHOD GContentHandler::LaunchHelperApp (void)
 {
 	nsCOMPtr<nsIExternalHelperAppService> helperService;
@@ -232,7 +222,7 @@ NS_METHOD GContentHandler::CheckAppSupportScheme (void)
 	{
 		char *uri_scheme = (char *)l->data;
 
-		if (mScheme.Equals (uri_scheme))
+		if (strcmp (mScheme.get(), uri_scheme) == 0)
 		{
 			mAppSupportScheme = PR_TRUE;
 		}
@@ -251,23 +241,16 @@ NS_METHOD GContentHandler::Init (void)
 	mLauncher->GetMIMEInfo (getter_AddRefs(MIMEInfo));
 	NS_ENSURE_TRUE (MIMEInfo, NS_ERROR_FAILURE);
 
-#if MOZILLA_SNAPSHOT < 20
-	rv = MIMEInfo->GetMIMEType (&mMimeType);
-#else
+#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
 	rv = MIMEInfo->GetMIMEType (mMimeType);
+#else
+	rv = MIMEInfo->GetMIMEType (&mMimeType);
 #endif
 
-#if MOZILLA_SNAPSHOT > 11
 	mLauncher->GetTargetFile (getter_AddRefs(mTempFile));
 
 	mLauncher->GetSource (getter_AddRefs(mUri));
 	NS_ENSURE_TRUE (mUri, NS_ERROR_FAILURE);
-#else
-	PRInt64 TimeDownloadStarted;
-	rv = mLauncher->GetDownloadInfo (getter_AddRefs(mUri),
-					&TimeDownloadStarted,
-					getter_AddRefs(mTempFile));
-#endif
 	
 	rv = mUri->GetSpec (mUrl);
 	rv = mUri->GetScheme (mScheme);
@@ -288,7 +271,7 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 
 	action_label =  (mAction == CONTENT_ACTION_OPEN) ||
 			(mAction == CONTENT_ACTION_OPEN_TMP) ?
-			_("_Open") : _("_Download");
+			GTK_STOCK_OPEN : EPHY_STOCK_DOWNLOAD;
 
 	dialog = gtk_dialog_new_with_buttons
 		("", parentWindow, GTK_DIALOG_NO_SEPARATOR,
@@ -376,19 +359,16 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 
 	auto_downloads = eel_gconf_get_boolean (CONF_AUTO_DOWNLOADS);
 
-#if MOZILLA_SNAPSHOT < 20
-	mHelperApp = gnome_vfs_mime_get_default_application (mMimeType);
-#else
+#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
 	mHelperApp = gnome_vfs_mime_get_default_application (mMimeType.get());
-#endif
-	CheckAppSupportScheme ();
-
-#if MOZILLA_SNAPSHOT < 20
-	mPermission = ephy_embed_shell_check_mime (embed_shell, mMimeType);
-#else
 	mPermission = ephy_embed_shell_check_mime (embed_shell, mMimeType.get());
+#else
+	mHelperApp = gnome_vfs_mime_get_default_application (mMimeType);
+	mPermission = ephy_embed_shell_check_mime (embed_shell, mMimeType);
 #endif
 
+	CheckAppSupportScheme ();
+
 	if (auto_downloads)
 	{
 		mAction = CONTENT_ACTION_OPEN;
@@ -414,23 +394,26 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 
 	if (mAction == CONTENT_ACTION_OPEN)
 	{
+		nsEmbedString desc;
+
+		NS_CStringToUTF16 (nsEmbedCString ("gnome-default"),
+			           NS_CSTRING_ENCODING_UTF8, desc);
+
 		/* HACK we use the application description to ask
 		   MozDownload to open the file when download
 		   is finished */
-#if MOZILLA_SNAPSHOT < 20
-		mimeInfo->SetApplicationDescription
-			(NS_LITERAL_STRING ("gnome-default").get());
+#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+		mimeInfo->SetApplicationDescription (desc);
 #else
-		mimeInfo->SetApplicationDescription
-			(NS_LITERAL_STRING ("gnome-default"));
+		mimeInfo->SetApplicationDescription (desc.get());
 #endif
 	}
 	else
 	{
-#if MOZILLA_SNAPSHOT < 20
-		mimeInfo->SetApplicationDescription (nsnull);
+#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+		mimeInfo->SetApplicationDescription (nsEmbedString ());
 #else
-		mimeInfo->SetApplicationDescription (NS_LITERAL_STRING (""));
+		mimeInfo->SetApplicationDescription (nsnull);
 #endif
 	}
 
